from .submodule import public_chain
from .submodule import _private_made_public as now_public_function
from .submodule import public_multiple_imports


def module_level_function(foo, bar):
    """A module level method"""
    pass
